@@ -1,4 +1,4 @@
 library(testthat)
 library(mitre)
 
-testthat::test_check("mitre")
+test_check("mitre")
